import {FC, useCallback, useEffect, useState} from "react";
import {View} from "@tarojs/components";
import styles from './list.module.scss'
import Taro, {useReachBottom, useRouter} from "@tarojs/taro";
import Collapse from "@/components/collapse/collapse";
import {illnessApi} from "@/api/illness";
import Empty from "@/components/empty/empty";

const BrandList: FC = () => {
  const params = useRouter().params as unknown as { id: number }
  const [page, setPage] = useState(1)
  const [brands, setBrands] = useState<any[]>([])
  const [total, setTotal] = useState(0)
  const [fetchDone,setFetchDone] = useState(false)

  useEffect(() => {
    Taro.showLoading({
      title: '加载中',
      mask: true
    })
    setTimeout(function () {
      Taro.hideLoading()
      setFetchDone(true)
    }, 800)
    getData()
  }, [page])

  const getData = useCallback(async () => {
    try {
      const data = await illnessApi.list(params.id, 1, 100)
      setTotal(data.total)
      setBrands([
        ...data.list
      ])
      Taro.setNavigationBarTitle({title: data.list?.[0].resourceCategories?.[0]?.name ?? '文章列表'})
    } catch (e) {
    }
  }, [page])


  useReachBottom(useCallback(() => {
    if (brands?.length < total) {
      setPage(page + 1)
    }
  }, [total, brands]))


  return (
    <View className='p-2' style={{display:fetchDone?'block':'none'}}>
      {
        brands.length > 0 ?
          brands.map((d) =>
            <View className={styles.box}>
              <View className={styles.rightBox}>
                <Collapse title={d.name} children={
                  <>
                    {
                      d.articles?.map((d) => <View
                          onClick={() => {
                            Taro.navigateTo({url: `/pages/preview/illness/article/article?id=${d.id}`})
                          }}
                          className='py-3 font-36'
                          style={{borderBottom: "1px solid #ddd"}}
                        >{d.title}</View>
                      )
                    }
                  </>
                }></Collapse>
              </View>
            </View>
          ) : <Empty name='暂无数据'/>
      }
    </View>
  )
}

export default BrandList
